Green Unicorn - News

# gunicorn

get the source in git then send feedback

# News

## 0.5 / 2010-02-20

- Added configuration file handler.
- Added support for pre/post fork hooks
- Added support for before_exec hook
- Added support for unix sockets
- Added launch of workers processes under different user/group
- Added umask option
- Added SCRIPT_NAME support
- Better support of some exotic settings for Django projects
- Better support of Paste-compatible applicatins
- Some refactoring to make the code easier to hack
- Allow multiple keys in request and response headers